@@ -1,4 +1,3 @@
-//
 // lib.rs
 // Copyright: (c) 2015-2021, Oleg Lelenkov
 // Distributed under terms of the BSD 3-Clause license.
@@ -17,6 +16,7 @@ pub use serialize::serialize;
 
 #[cfg(feature = "loaders")]
 pub use loaders::{
-    UniLoader, FileReader, UniNodeLoadError, register_loader, is_available_loader,
-    set_default_reader, from_file, from_string, from_file_base,
+    UniLoader, FileReader, UniNodeLoadError, register_loader,
+    is_available_loader, set_default_reader, from_file, from_string,
+    from_file_base,
 };
