@@ -169,10 +169,9 @@ where
 
 pub fn from_file<P: AsRef<Path>>(path: P) -> Result {
     let path = path.as_ref();
-    let ext = path
-        .extension()
-        .and_then(|e| e.to_str())
-        .ok_or(UniNodeLoadError::FileExtension(path.display().to_string()))?;
+    let ext = path.extension().and_then(|e| e.to_str()).ok_or_else(|| {
+        UniNodeLoadError::FileExtension(path.display().to_string())
+    })?;
 
     let reader = READER.read().unwrap();
     from_reader(ext, path, &reader)
